@@ -3,6 +3,7 @@
 #![doc(html_favicon_url = "https://licensebat.com/images/not_used/favicons_red/favicon.ico")]
 #![warn(missing_docs)]
 
+use licensebat_core::RetrievedDependency;
 use structopt::StructOpt;
 
 #[tokio::main]
@@ -10,12 +11,26 @@ async fn main() -> anyhow::Result<()> {
     dotenv::dotenv().ok();
     set_up_tracing();
     let cli = licensebat_cli::Cli::from_args();
-    let deps = licensebat_cli::run(cli).await?;
+    let licensebat_cli::RunResult {
+        licrc,
+        dependencies,
+    } = licensebat_cli::run(cli).await?;
 
-    // TODO: in case of errors in the licenses we should probably exit with a non-zero code
-    // and probably provide some information about the error(s).
+    show_result(&dependencies)?;
 
-    //  show the result in json format
+    if licrc.behavior.do_not_block_pr.unwrap_or(false) {
+        Ok(())
+    } else {
+        let has_invalid_dependencies = dependencies.iter().any(|d| !d.is_valid);
+        if has_invalid_dependencies {
+            std::process::exit(1);
+        }
+        Ok(())
+    }
+}
+
+/// Prints the dependencies in the stdout
+fn show_result(deps: &[RetrievedDependency]) -> anyhow::Result<()> {
     tracing::debug!("Showing results");
     let json = if cfg!(debug_assertions) {
         serde_json::to_string_pretty(&deps)
@@ -23,12 +38,11 @@ async fn main() -> anyhow::Result<()> {
         serde_json::to_string(&deps)
     }?;
     println!("{}", json);
-
-    // TODO: add option to write the result to a file?
-
     Ok(())
 }
 
+/// Sets up the tracing subscriber.
+/// It will use a pretty print in debug and json in --release mode.
 fn set_up_tracing() {
     let tracing = tracing_subscriber::fmt()
         .with_env_filter(tracing_subscriber::EnvFilter::from_default_env());
